==> plee-the-bear_0.4.1.orig.tar.gz: plee-the-bear-0.4.1/bear-factory/bear-editor/src/bf/image_pool.hpp <==
/*
    Bear Engine - Editor library

    Copyright (C) 2005-2009 Julien Jorge, Sebastien Angibaud

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    contact: plee-the-bear@gamned.org

    Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file bf/image_pool.hpp
 * \brief A singleton containing all image resources.
 * \author Julien Jorge
 */
#ifndef __BF_IMAGE_POOL_HPP__
#define __BF_IMAGE_POOL_HPP__

#include "bf/libeditor_export.hpp"

#include <boost/filesystem/convenience.hpp>
#include <claw/basic_singleton.hpp>
#include <claw/iterator.hpp>
#include <claw/functional.hpp>
#include <map>

#include <wx/bitmap.h>
#include <wx/image.h>

namespace bf
{
  /**
   * \brief A singleton containing all image resources.
   * \author Julien Jorge
   */
  class BEAR_EDITOR_EXPORT image_pool
    : public claw::concept::basic_singleton<image_pool>
  {
  private:
    typedef std::map<wxString, wxBitmap> image_map;

  public:
    typedef claw::wrapped_iterator
    < const wxString,
      image_map::const_iterator,
      claw::const_pair_first<image_map::value_type> >
    ::iterator_type const_iterator;

  public:
    image_pool();

    void scan_directory( const std::string& dir_path );

    wxBitmap get_image( const wxString& image_name ) const;
    wxBitmap get_thumbnail( const wxString& image_name ) const;

    const_iterator begin() const;
    const_iterator end() const;

  private:
    void add_image( const std::string& root, const std::string& file_path );

    wxBitmap load_thumb( const std::string& path ) const;
    void load_image_data( const wxString& name ) const;
    wxImage load_image( const std::string& path ) const;

    void scan_sub_directory
    ( const std::string& root, const boost::filesystem::path& dir );
    bool supported_extension( const std::string& path ) const;

  public:
    /** \brief The maximum size of the thumbnails. */
    static const wxSize s_thumb_size;

  private:
    /** \brief The item classes. */
    mutable image_map m_image;

    /** \brief The thumbnails of the images. */
    mutable image_map m_thumbnail;

  }; // class image_pool
} // namespace bf

#endif // __BF_IMAGE_POOL_HPP__

==> plee-the-bear_0.5.1.orig.tar.gz: plee-the-bear-0.5.1/bear-factory/bear-editor/src/bf/image_pool.hpp <==
/*
    Bear Engine - Editor library

    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    contact: plee-the-bear@gamned.org

    Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file bf/image_pool.hpp
 * \brief A singleton containing all image resources.
 * \author Julien Jorge
 */
#ifndef __BF_IMAGE_POOL_HPP__
#define __BF_IMAGE_POOL_HPP__

#include "bf/libeditor_export.hpp"

#include <claw/basic_singleton.hpp>
#include <claw/iterator.hpp>
#include <claw/functional.hpp>
#include <map>

#include <wx/bitmap.h>

namespace bf
{
  /**
   * \brief A singleton containing all image resources.
   * \author Julien Jorge
   */
  class BEAR_EDITOR_EXPORT image_pool
    : public claw::pattern::basic_singleton<image_pool>
  {
  private:
    typedef std::map<wxString, wxBitmap> image_map;

    /** \brief Function object passed to bf::scan_dir to load the thumbnails. */
    struct load_thumb_func
    {
    public:
      load_thumb_func( image_map& t, const std::string& r );

      void operator()( const std::string& path );

      static wxBitmap load( const std::string& path );

    public:
      /** \brief The thumbnails of the images. */
      image_map& thumb;

    private:
      /** \brief The directory from which the search started. */
      std::string m_root;

    }; // struct load_thumb_func

  public:
    typedef claw::wrapped_iterator
    < const wxString,
      image_map::const_iterator,
      claw::const_pair_first<image_map::value_type> >
    ::iterator_type const_iterator;

  public:
    image_pool();

    void clear();
    void scan_directory( const std::string& dir_path );

    wxBitmap get_image( const wxString& image_name ) const;
    wxBitmap get_thumbnail( const wxString& image_name ) const;

    const_iterator begin() const;
    const_iterator end() const;

  private:
    void add_image( const std::string& root, const std::string& file_path );

    void load_image_data( const wxString& name ) const;

  public:
    /** \brief The maximum size of the thumbnails. */
    static const wxSize s_thumb_size;

  private:
    /** \brief The images used in the application. */
    mutable image_map m_image;

    /** \brief The thumbnails of the images. */
    mutable image_map m_thumbnail;

  }; // class image_pool
} // namespace bf

#endif // __BF_IMAGE_POOL_HPP__
